==> teradataml-16.20.0.1.post0-py3-none-any.whl: teradataml/analytics/mle/TextClassifierEvaluator.py <==
#!/usr/bin/python
# ################################################################## 
# 
# Copyright 2018 Teradata. All rights reserved.
# TERADATA CONFIDENTIAL AND TRADE SECRET
# 
# Primary Owner: Pankaj Purandare (pankajvinod.purandare@teradata.com)
# Secondary Owner: Mounika Kotha (mounika.kotha@teradata.com)
# 
# Version: 1.2
# Function Version: 1.3
# 
# ################################################################## 

from teradataml.common.wrapper_utils import AnalyticsWrapperUtils
from teradataml.common.utils import UtilFuncs
from teradataml.context.context import *
from teradataml.dataframe.dataframe import DataFrame
from teradataml.common.aed_utils import AedUtils
from teradataml.analytics.analytic_query_generator import AnalyticQueryGenerator
from teradataml.common.exceptions import TeradataMlException
from teradataml.common.messages import Messages
from teradataml.common.messagecodes import MessageCodes
from teradataml.common.constants import TeradataConstants
from teradataml.dataframe.dataframe_utils import DataFrameUtils as df_utils
from teradataml.options.display import display
from teradataml.analytics.mle.TextClassifier import TextClassifier

class TextClassifierEvaluator:
    
    def __init__(self,
        object = None,
        obs_column = None,
        predict_column = None,
        object_sequence_column = None,
        object_order_column = None):
        """
        DESCRIPTION:
            The TextClassifierEvaluator function evaluates the precision, recall, 
            and F-measure of the trained model output by the function 
            TextClassifier.
        
        
        PARAMETERS:
            object:
                Required Argument.
                Specifies the teradataml DataFrame containing the model data from
                TextClassifier or instance of 'TextClassifier'.
                            
            object_order_column:
                Optional Argument.
                Specifies Order By columns for object.
                Values to this argument can be provided as list, if multiple columns 
                are used for ordering.
                Types: str OR list of Strings (str)
            
            obs_column:
                Required Argument.
                Specifies the name of the input teradataml DataFrame column that 
                contains the expected (correct) category.
                Types: str
            
            predict_column:
                Required Argument.
                Specifies the name of the input teradataml DataFrame column that 
                contains the predicted category.
                Types: str
            
            object_sequence_column:
                Optional Argument.
                Specifies the list of column(s) that uniquely identifies each row of 
                the input argument "object". The argument is used to ensure 
                deterministic results for functions which produce results that vary 
                from run to run.
                Types: str OR list of Strings (str)
        
        RETURNS:
            Instance of TextClassifierEvaluator.
            Output teradataml DataFrames can be accessed using attribute 
            references, such as TextClassifierEvaluatorObj.<attribute_name>.
            Output teradataml DataFrame attribute name is:
                result
        
        
        RAISES:
            TeradataMlException
        
        
        EXAMPLES:
            # Load example data.
            load_example_data("textclassifiertrainer", "texttrainer_input")
            load_example_data("textclassifier", "textclassifier_input")
            
            # Create teradataml DataFrame objects.    
            # The input table "texttrainer_input" contains text of the training 
            # documents and the category of the training documents.
            texttrainer_input = DataFrame.from_table("texttrainer_input")
            
            # The input table "textclassifier_input" contains the text to be 
            # classified.
            textclassifier_input = DataFrame.from_table("textclassifier_input")
            
            # The model file "knn.bin" generated by TextClassifierTrainer function 
            # is used by TextClassifier to classify the input text.
            textclassifiertrainer_out = TextClassifierTrainer(data=texttrainer_input,
                                                              text_column='content',
                                                              category_column='category',
                                                              classifier_type='knn',
                                                              model_file='knn.bin',    
                                                              nlp_parameters=['useStem:true','stopwordsFile:stopwords.txt'],
                                                              classifier_parameters='compress:0.9',
                                                              feature_selection='DF:[0.1:0.99]',
                                                              data_sequence_column='id'
                                                              )
            
            textclassifier_out = TextClassifier(newdata = textclassifier_input,
                                                model_file = "knn.bin",
                                                text_column = "content",
                                                accumulate = ["id","category"],
                                                newdata_order_column = "id"
                                                )
            
            # Example 1 - TextClassifierEvaluator uses the output of TextClassifier.
            textclassifierevaluator_out1 = TextClassifierEvaluator(object=textclassifier_out,
                                             obs_column='category',
                                             predict_column='out_category',
                                             object_sequence_column='id',
                                             object_order_column='id'
                                             )
            
            # Print the result teradataml DataFrame
            print(textclassifierevaluator_out1)
            
            
            # Example 2 - Alternatively, persist and use the output table of TextClassifier.
            copy_to_sql(textclassifier_out.result, "textclassifier_output")
            textclassifier_output =  DataFrame.from_table("textclassifier_output")
            
            textclassifierevaluator_out2 = TextClassifierEvaluator(object=textclassifier_output,
                                             obs_column='category',
                                             predict_column='out_category',
                                             object_sequence_column='id',
                                             object_order_column='id'
                                             )
            
            # Print the results. 
            print(textclassifierevaluator_out2.result)
            
        
        """
        self.object  = object 
        self.obs_column  = obs_column 
        self.predict_column  = predict_column 
        self.object_sequence_column  = object_sequence_column 
        self.object_order_column  = object_order_column 
        
        # Create TeradataPyWrapperUtils instance which contains validation functions.
        self.__awu = AnalyticsWrapperUtils()
        self.__aed_utils = AedUtils()
        
        # Create argument information matrix to do parameter checking
        self.__arg_info_matrix = []
        self.__arg_info_matrix.append(["object", self.object, False, (DataFrame)])
        self.__arg_info_matrix.append(["object_order_column", self.object_order_column, True, (str,list)])
        self.__arg_info_matrix.append(["obs_column", self.obs_column, False, (str)])
        self.__arg_info_matrix.append(["predict_column", self.predict_column, False, (str)])
        self.__arg_info_matrix.append(["object_sequence_column", self.object_sequence_column, True, (str,list)])
        
        # Perform the function validations
        self.__validate()
        # Generate the ML query
        self.__form_tdml_query()
        # Execute ML query
        self.__execute()
        
    def __validate(self):
        """
        Function to validate sqlmr function arguments, which verifies missing 
        arguments, input argument and table types. Also processes the 
        argument values.
        """
        if isinstance(self.object, TextClassifier):
            self.object = self.object._mlresults[0]
        
        # Make sure that a non-NULL value has been supplied for all mandatory arguments
        self.__awu._validate_missing_required_arguments(self.__arg_info_matrix)
        
        # Make sure that a non-NULL value has been supplied correct type of argument
        self.__awu._validate_argument_types(self.__arg_info_matrix)
        
        # Check to make sure input table types are strings or data frame objects or of valid type.
        self.__awu._validate_input_table_datatype(self.object, "object", TextClassifier)
        
        # Check whether the input columns passed to the argument are not empty.
        # Also check whether the input columns passed to the argument valid or not.
        self.__awu._validate_input_columns_not_empty(self.obs_column, "obs_column")
        self.__awu._validate_dataframe_has_argument_columns(self.obs_column, "obs_column", self.object, "object", False)
        
        self.__awu._validate_input_columns_not_empty(self.predict_column, "predict_column")
        self.__awu._validate_dataframe_has_argument_columns(self.predict_column, "predict_column", self.object, "object", False)
        
        self.__awu._validate_input_columns_not_empty(self.object_sequence_column, "object_sequence_column")
        self.__awu._validate_dataframe_has_argument_columns(self.object_sequence_column, "object_sequence_column", self.object, "object", False)
        
        self.__awu._validate_input_columns_not_empty(self.object_order_column, "object_order_column")
        self.__awu._validate_dataframe_has_argument_columns(self.object_order_column, "object_order_column", self.object, "object", False)
        
        
    def __form_tdml_query(self):
        """
        Function to generate the analytical function queries. The function defines 
        variables and list of arguments required to form the query.
        """
        
        # Output table arguments list
        self.__func_output_args_sql_names = []
        self.__func_output_args = []
        
        # Generate lists for rest of the function arguments
        self.__func_other_arg_sql_names = []
        self.__func_other_args = []
        self.__func_other_arg_json_datatypes = []
        
        self.__func_other_arg_sql_names.append("ObsColumn")
        self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(UtilFuncs._teradata_quote_arg(self.obs_column,"\""),"'"))
        self.__func_other_arg_json_datatypes.append("COLUMNS")
        
        self.__func_other_arg_sql_names.append("PredictColumn")
        self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(UtilFuncs._teradata_quote_arg(self.predict_column,"\""),"'"))
        self.__func_other_arg_json_datatypes.append("COLUMNS")
        
        # Generate lists for rest of the function arguments
        sequence_input_by_list = []
        if self.object_sequence_column is not None:
            sequence_input_by_list.append("input:" + UtilFuncs._teradata_collapse_arglist(self.object_sequence_column,""))
        
        if len(sequence_input_by_list) > 0:
            self.__func_other_arg_sql_names.append("SequenceInputBy")
            self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(sequence_input_by_list,"'"))
            self.__func_other_arg_json_datatypes.append("STRING")
        
        
        # Declare empty lists to hold input table information.
        self.__func_input_arg_sql_names = []
        self.__func_input_table_view_query = []
        self.__func_input_dataframe_type = []
        self.__func_input_distribution = []
        self.__func_input_partition_by_cols = []
        self.__func_input_order_by_cols = []
        
        # Process object
        self.__table_ref = self.__awu._teradata_on_clause_from_dataframe(self.object, False)
        self.__func_input_distribution.append("FACT")
        self.__func_input_arg_sql_names.append("input")
        self.__func_input_table_view_query.append(self.__table_ref["ref"])
        self.__func_input_dataframe_type.append(self.__table_ref["ref_type"])
        self.__func_input_partition_by_cols.append("1")
        self.__func_input_order_by_cols.append(UtilFuncs._teradata_collapse_arglist(self.object_order_column,"\""))
        
        function_name = "TextClassifierEvaluator"
        # Create instance to generate SQLMR.
        aqg_obj = AnalyticQueryGenerator(function_name 
                ,self.__func_input_arg_sql_names 
                ,self.__func_input_table_view_query 
                ,self.__func_input_dataframe_type 
                ,self.__func_input_distribution 
                ,self.__func_input_partition_by_cols 
                ,self.__func_input_order_by_cols 
                ,self.__func_other_arg_sql_names 
                ,self.__func_other_args 
                ,self.__func_other_arg_json_datatypes 
                ,self.__func_output_args_sql_names 
                ,self.__func_output_args)
        # Invoke call to SQL-MR generation.
        self.sqlmr_query = aqg_obj._gen_sqlmr_select_stmt_sql()
        
        # Print SQL-MR query if requested to do so.
        if display.print_sqlmr_query:
            print(self.sqlmr_query)
        
    def __execute(self):
        """
        Function to execute SQL-MR queries. 
        Create DataFrames for the required SQL-MR outputs.
        """
        # Generate STDOUT table name and add it to the output table list.
        sqlmr_stdout_temp_tablename = UtilFuncs._generate_temp_table_name(prefix = "td_sqlmr_out_", use_default_database = True, gc_on_quit = True, quote=False)
        try:
            UtilFuncs._create_view(sqlmr_stdout_temp_tablename, self.sqlmr_query)
        except Exception as emsg:
            raise TeradataMlException(Messages.get_message(MessageCodes.TDMLDF_EXEC_SQL_FAILED, str(emsg)), MessageCodes.TDMLDF_EXEC_SQL_FAILED)
        
        # Update output table data frames.
        self._mlresults = []
        self.result = self.__awu._create_data_set_object(df_input=UtilFuncs._extract_table_name(sqlmr_stdout_temp_tablename), source_type="table", database_name=UtilFuncs._extract_db_name(sqlmr_stdout_temp_tablename))
        self._mlresults.append(self.result)
        
    def __repr__(self):
        """
        Returns the string representation for a TextClassifierEvaluator class instance.
        """
        repr_string="############ STDOUT Output ############"
        repr_string = "{}\n\n{}".format(repr_string,self.result)
        return repr_string

==> teradataml-16.20.0.4-py3-none-any.whl: teradataml/analytics/mle/TextClassifierEvaluator.py <==
#!/usr/bin/python
# ################################################################## 
# 
# Copyright 2018 Teradata. All rights reserved.
# TERADATA CONFIDENTIAL AND TRADE SECRET
# 
# Primary Owner: Pankaj Purandare (pankajvinod.purandare@teradata.com)
# Secondary Owner: Mounika Kotha (mounika.kotha@teradata.com)
# 
# Version: 1.2
# Function Version: 1.3
# 
# ################################################################## 

import inspect
from teradataml.common.wrapper_utils import AnalyticsWrapperUtils
from teradataml.common.utils import UtilFuncs
from teradataml.context.context import *
from teradataml.dataframe.dataframe import DataFrame
from teradataml.common.aed_utils import AedUtils
from teradataml.analytics.analytic_query_generator import AnalyticQueryGenerator
from teradataml.common.exceptions import TeradataMlException
from teradataml.common.messages import Messages
from teradataml.common.messagecodes import MessageCodes
from teradataml.common.constants import TeradataConstants
from teradataml.dataframe.dataframe_utils import DataFrameUtils as df_utils
from teradataml.options.display import display
from teradataml.analytics.mle.TextClassifier import TextClassifier

class TextClassifierEvaluator:
    
    def __init__(self,
        object = None,
        obs_column = None,
        predict_column = None,
        object_sequence_column = None,
        object_order_column = None):
        """
        DESCRIPTION:
            The TextClassifierEvaluator function evaluates the precision, recall,
            and F-measure of the trained model output by the function
            TextClassifier.


        PARAMETERS:
            object:
                Required Argument.
                Specifies the teradataml DataFrame containing the model data from
                TextClassifier or instance of 'TextClassifier'.

            object_order_column:
                Optional Argument.
                Specifies Order By columns for object.
                Values to this argument can be provided as list, if multiple columns
                are used for ordering.
                Types: str OR list of Strings (str)

            obs_column:
                Required Argument.
                Specifies the name of the input teradataml DataFrame column that
                contains the expected (correct) category.
                Types: str

            predict_column:
                Required Argument.
                Specifies the name of the input teradataml DataFrame column that
                contains the predicted category.
                Types: str

            object_sequence_column:
                Optional Argument.
                Specifies the list of column(s) that uniquely identifies each row of
                the input argument "object". The argument is used to ensure
                deterministic results for functions which produce results that vary
                from run to run.
                Types: str OR list of Strings (str)

        RETURNS:
            Instance of TextClassifierEvaluator.
            Output teradataml DataFrames can be accessed using attribute
            references, such as TextClassifierEvaluatorObj.<attribute_name>.
            Output teradataml DataFrame attribute name is:
                result


        RAISES:
            TeradataMlException


        EXAMPLES:
            # Load example data.
            load_example_data("textclassifiertrainer", "texttrainer_input")
            load_example_data("textclassifier", "textclassifier_input")

            # Create teradataml DataFrame objects.
            # The input table "texttrainer_input" contains text of the training
            # documents and the category of the training documents.
            texttrainer_input = DataFrame.from_table("texttrainer_input")

            # The input table "textclassifier_input" contains the text to be
            # classified.
            textclassifier_input = DataFrame.from_table("textclassifier_input")

            # The model file "knn.bin" generated by TextClassifierTrainer function
            # is used by TextClassifier to classify the input text.
            textclassifiertrainer_out = TextClassifierTrainer(data=texttrainer_input,
                                                              text_column='content',
                                                              category_column='category',
                                                              classifier_type='knn',
                                                              model_file='knn.bin',
                                                              nlp_parameters=['useStem:true','stopwordsFile:stopwords.txt'],
                                                              classifier_parameters='compress:0.9',
                                                              feature_selection='DF:[0.1:0.99]',
                                                              data_sequence_column='id'
                                                              )

            textclassifier_out = TextClassifier(newdata = textclassifier_input,
                                                model_file = "knn.bin",
                                                text_column = "content",
                                                accumulate = ["id","category"],
                                                newdata_order_column = "id"
                                                )

            # Example 1 - TextClassifierEvaluator uses the output of TextClassifier.
            textclassifierevaluator_out1 = TextClassifierEvaluator(object=textclassifier_out,
                                             obs_column='category',
                                             predict_column='out_category',
                                             object_sequence_column='id',
                                             object_order_column='id'
                                             )

            # Print the result teradataml DataFrame
            print(textclassifierevaluator_out1)


            # Example 2 - Alternatively, persist and use the output table of TextClassifier.
            copy_to_sql(textclassifier_out.result, "textclassifier_output")
            textclassifier_output =  DataFrame.from_table("textclassifier_output")

            textclassifierevaluator_out2 = TextClassifierEvaluator(object=textclassifier_output,
                                             obs_column='category',
                                             predict_column='out_category',
                                             object_sequence_column='id',
                                             object_order_column='id'
                                             )

            # Print the results.
            print(textclassifierevaluator_out2.result)

        
        """
        self.object  = object 
        self.obs_column  = obs_column 
        self.predict_column  = predict_column 
        self.object_sequence_column  = object_sequence_column 
        self.object_order_column  = object_order_column 
        
        # Create TeradataPyWrapperUtils instance which contains validation functions.
        self.__awu = AnalyticsWrapperUtils()
        self.__aed_utils = AedUtils()
        
        # Create argument information matrix to do parameter checking
        self.__arg_info_matrix = []
        self.__arg_info_matrix.append(["object", self.object, False, (DataFrame)])
        self.__arg_info_matrix.append(["object_order_column", self.object_order_column, True, (str,list)])
        self.__arg_info_matrix.append(["obs_column", self.obs_column, False, (str)])
        self.__arg_info_matrix.append(["predict_column", self.predict_column, False, (str)])
        self.__arg_info_matrix.append(["object_sequence_column", self.object_sequence_column, True, (str,list)])
        
        if inspect.stack()[1][3] != '_from_model_manager':
            # Perform the function validations
            self.__validate()
            # Generate the ML query
            self.__form_tdml_query()
            # Execute ML query
            self.__execute()
        
    def __validate(self):
        """
        Function to validate sqlmr function arguments, which verifies missing 
        arguments, input argument and table types. Also processes the 
        argument values.
        """
        if isinstance(self.object, TextClassifier):
            self.object = self.object._mlresults[0]
        
        # Make sure that a non-NULL value has been supplied for all mandatory arguments
        self.__awu._validate_missing_required_arguments(self.__arg_info_matrix)
        
        # Make sure that a non-NULL value has been supplied correct type of argument
        self.__awu._validate_argument_types(self.__arg_info_matrix)
        
        # Check to make sure input table types are strings or data frame objects or of valid type.
        self.__awu._validate_input_table_datatype(self.object, "object", TextClassifier)
        
        # Check whether the input columns passed to the argument are not empty.
        # Also check whether the input columns passed to the argument valid or not.
        self.__awu._validate_input_columns_not_empty(self.obs_column, "obs_column")
        self.__awu._validate_dataframe_has_argument_columns(self.obs_column, "obs_column", self.object, "object", False)
        
        self.__awu._validate_input_columns_not_empty(self.predict_column, "predict_column")
        self.__awu._validate_dataframe_has_argument_columns(self.predict_column, "predict_column", self.object, "object", False)
        
        self.__awu._validate_input_columns_not_empty(self.object_sequence_column, "object_sequence_column")
        self.__awu._validate_dataframe_has_argument_columns(self.object_sequence_column, "object_sequence_column", self.object, "object", False)
        
        self.__awu._validate_input_columns_not_empty(self.object_order_column, "object_order_column")
        self.__awu._validate_dataframe_has_argument_columns(self.object_order_column, "object_order_column", self.object, "object", False)
        
        
    def __form_tdml_query(self):
        """
        Function to generate the analytical function queries. The function defines 
        variables and list of arguments required to form the query.
        """
        
        # Output table arguments list
        self.__func_output_args_sql_names = []
        self.__func_output_args = []
        
        # Generate lists for rest of the function arguments
        self.__func_other_arg_sql_names = []
        self.__func_other_args = []
        self.__func_other_arg_json_datatypes = []
        
        self.__func_other_arg_sql_names.append("ObsColumn")
        self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(UtilFuncs._teradata_quote_arg(self.obs_column,"\""),"'"))
        self.__func_other_arg_json_datatypes.append("COLUMNS")
        
        self.__func_other_arg_sql_names.append("PredictColumn")
        self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(UtilFuncs._teradata_quote_arg(self.predict_column,"\""),"'"))
        self.__func_other_arg_json_datatypes.append("COLUMNS")
        
        # Generate lists for rest of the function arguments
        sequence_input_by_list = []
        if self.object_sequence_column is not None:
            sequence_input_by_list.append("input:" + UtilFuncs._teradata_collapse_arglist(self.object_sequence_column,""))
        
        if len(sequence_input_by_list) > 0:
            self.__func_other_arg_sql_names.append("SequenceInputBy")
            self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(sequence_input_by_list,"'"))
            self.__func_other_arg_json_datatypes.append("STRING")
        
        
        # Declare empty lists to hold input table information.
        self.__func_input_arg_sql_names = []
        self.__func_input_table_view_query = []
        self.__func_input_dataframe_type = []
        self.__func_input_distribution = []
        self.__func_input_partition_by_cols = []
        self.__func_input_order_by_cols = []
        
        # Process object
        self.__table_ref = self.__awu._teradata_on_clause_from_dataframe(self.object, False)
        self.__func_input_distribution.append("FACT")
        self.__func_input_arg_sql_names.append("input")
        self.__func_input_table_view_query.append(self.__table_ref["ref"])
        self.__func_input_dataframe_type.append(self.__table_ref["ref_type"])
        self.__func_input_partition_by_cols.append("1")
        self.__func_input_order_by_cols.append(UtilFuncs._teradata_collapse_arglist(self.object_order_column,"\""))
        
        function_name = "TextClassifierEvaluator"
        # Create instance to generate SQLMR.
        aqg_obj = AnalyticQueryGenerator(function_name 
                ,self.__func_input_arg_sql_names 
                ,self.__func_input_table_view_query 
                ,self.__func_input_dataframe_type 
                ,self.__func_input_distribution 
                ,self.__func_input_partition_by_cols 
                ,self.__func_input_order_by_cols 
                ,self.__func_other_arg_sql_names 
                ,self.__func_other_args 
                ,self.__func_other_arg_json_datatypes 
                ,self.__func_output_args_sql_names 
                ,self.__func_output_args 
                ,engine = "ENGINE_ML")
        # Invoke call to SQL-MR generation.
        self.sqlmr_query = aqg_obj._gen_sqlmr_select_stmt_sql()
        
        # Print SQL-MR query if requested to do so.
        if display.print_sqlmr_query:
            print(self.sqlmr_query)
        
    def __execute(self):
        """
        Function to execute SQL-MR queries. 
        Create DataFrames for the required SQL-MR outputs.
        """
        # Generate STDOUT table name and add it to the output table list.
        sqlmr_stdout_temp_tablename = UtilFuncs._generate_temp_table_name(prefix = "td_sqlmr_out_", use_default_database = True, gc_on_quit = True, quote=False)
        try:
            UtilFuncs._create_view(sqlmr_stdout_temp_tablename, self.sqlmr_query)
        except Exception as emsg:
            raise TeradataMlException(Messages.get_message(MessageCodes.TDMLDF_EXEC_SQL_FAILED, str(emsg)), MessageCodes.TDMLDF_EXEC_SQL_FAILED)
        
        # Update output table data frames.
        self._mlresults = []
        self.result = self.__awu._create_data_set_object(df_input=UtilFuncs._extract_table_name(sqlmr_stdout_temp_tablename), source_type="table", database_name=UtilFuncs._extract_db_name(sqlmr_stdout_temp_tablename))
        self._mlresults.append(self.result)
        
    @classmethod
    def _from_model_manager(cls,
        result = None,
        **kwargs):
        """
        Classmethod which will be used by Model Manager, to instantiate this wrapper class.
        """
        kwargs.pop("result", None)
        
        # Let's create an object of this class.
        obj = cls(**kwargs)
        obj.result  = result 
        
        # Update output table data frames.
        obj._mlresults = []
        obj.result = obj.__awu._create_data_set_object(df_input=UtilFuncs._extract_table_name(obj.result), source_type="table", database_name=UtilFuncs._extract_db_name(obj.result))
        obj._mlresults.append(obj.result)
        return obj
        
    def __repr__(self):
        """
        Returns the string representation for a TextClassifierEvaluator class instance.
        """
        repr_string="############ STDOUT Output ############"
        repr_string = "{}\n\n{}".format(repr_string,self.result)
        return repr_string
